# -*- coding:utf-8 -*-
#
# Copyright (C) 2019-2020 Alibaba Group Holding Limited


from __future__ import print_function

import os
from thead_tools import *


class Toolchain(Command):
    common = True
    helpSummary = "Install toolchain"
    helpUsage = """
%prog [--all] [--csky] [--riscv]
"""
    helpDescription = """
Install toolchain.
"""

    def _Options(self, p):
        p.add_option('-c', '--csky',
                     dest='install_csky', action='store_true',
                     help=' install csky toolchain')
        p.add_option('-r', '--riscv',
                     dest='install_riscv', action='store_true',
                     help=' install riscv toolchain')
        p.add_option('-a', '--all',
                     dest='install_all', action='store_true',
                     help=' install csky toolchain and riscv toolchain')

        p.add_option('-o', '--output',
                     dest='output', action='store', type='str', default=None,
                     help=' install target directory')

    def Execute(self, opt, args):
        need_usage = True
        tool = ToolchainYoC(opt.output)
        if opt.install_all:
            tool.check_toolchain('csky-linux', 1)
            tool.check_toolchain('riscv64-linux', 1)
            need_usage = False
        else:
            if opt.install_csky:
                tool.check_toolchain('csky-linux', 1)
                need_usage = False
            if opt.install_riscv:
                tool.check_toolchain('riscv64-linux', 1)
                need_usage = False
        if need_usage:
            self.Usage()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from distutils.command.build_ext import build_ext as _build_ext
from distutils.core import Extension
import os
import sys
import platform
from codecs import open  # To use a consistent encoding

# Always prefer setuptools over distutils
from setuptools import setup, find_packages

def read(rel_path):
    here = os.path.abspath(os.path.dirname(__file__))
    with open(os.path.join(here, rel_path), 'r') as fp:
        return fp.read()

def get_version(rel_path):
    for line in read(rel_path).splitlines():
        if line.startswith('__version__'):
            # __version__ = "0.9"
            delim = '"' if '"' in line else "'"
            return line.split(delim)[1]
    else:
        raise RuntimeError("Unable to find version string.")

APP_NAME = 'thead_tools'

settings = dict()

settings.update(
    name=APP_NAME,
    version=get_version("thead_tools/cmd.py"),
    description='thead linux tools',
    author='Zhuzhg',
    author_email='zzg@ifnfn.com',
    packages=find_packages(),
    install_requires=[
        'pyserial'
    ],

    license='BSD',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    # data_files=[
    #     ('bin', ['thead_tools/build/product64']),
    #     ('bin', ['thead_tools/build/product32']),
    #     ('/usr/local/bin', ['thead_tools/build/product64']),
    #     ('/usr/local/bin', ['thead_tools/build/product32']),
    # ],
    entry_points={
        'console_scripts': [
            'thead = thead_tools.cmd:main',
            # 'cct = thead_tools.cmd:cct_main'
        ],
    },

    python_requires='>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*',
)


setup(**settings)


architecture = platform.architecture()

if architecture[0] == '64bit':
    product = '/usr/local/bin/product64'
else:
    product = '/usr/local/bin/product32'

try:
    os.symlink(product, '/usr/local/bin/product')
except:
    pass
